"use strict";var s=function(r,e){return function(){return e||r((e={exports:{}}).exports,e),e.exports}};var i=s(function(c,t){
var u=require('@stdlib/math-base-special-floor/dist');function n(r){return u(r)===r}t.exports=n
});var o=i();module.exports=o;
/** @license Apache-2.0 */
//# sourceMappingURL=index.js.map
